.. _api:

API
===

.. py:currentmodule:: disinfect

.. autoclass:: Mapping
   :members:
   :undoc-members:

.. autofunction:: validate
.. autofunction:: sanitize

.. autoclass:: MultiValueError
.. autoclass:: MappedValueError

.. autofunction:: Boolean
.. autofunction:: Date
.. autofunction:: DateTime
.. autofunction:: Email
.. autofunction:: Enum
.. autofunction:: Float
.. autofunction:: InstanceOf
.. autofunction:: Int
.. autofunction:: List
.. autofunction:: ListOf
.. autofunction:: Regex
.. autofunction:: Set
.. autofunction:: String
.. autofunction:: Upload

.. autoclass:: Test
   :members:
   :undoc-members:

.. autoclass:: Field
   :members:
   :undoc-members:

.. autofunction:: test_and_return
